View source: R/utils-time-helpers.R
| ts_get_date_columns | R Documentation |
Get date or datetime variables (column names)
ts_get_date_columns(.data)
.data |
An object of class |
ts_get_date_columns returns the column names of date or datetime variables
in a data frame.
A vector containing the column names that are of date/date-like classes.
Steven P. Sanderson II, MPH
Other Utility:
auto_stationarize(),
calibrate_and_plot(),
internal_ts_backward_event_tbl(),
internal_ts_both_event_tbl(),
internal_ts_forward_event_tbl(),
model_extraction_helper(),
ts_info_tbl(),
ts_is_date_class(),
ts_lag_correlation(),
ts_model_auto_tune(),
ts_model_compare(),
ts_model_rank_tbl(),
ts_model_spec_tune_template(),
ts_qq_plot(),
ts_scedacity_scatter_plot(),
ts_to_tbl(),
util_difflog_ts(),
util_doublediff_ts(),
util_doubledifflog_ts(),
util_log_ts(),
util_singlediff_ts()
ts_to_tbl(AirPassengers) %>%
ts_get_date_columns()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.