| ts_info_tbl | R Documentation |
This function will take in a data set and return to you a tibble of useful information.
ts_info_tbl(.data, .date_col)
.data |
The data you are passing to the function |
.date_col |
This is only needed if you are passing a tibble. |
This function can accept objects of the following classes:
ts
xts
mts
zoo
tibble/data.frame
The function will return the following pieces of information in a tibble:
name
class
frequency
start
end
var
length
A tibble
Steven P. Sanderson II, MPH
Other Utility:
auto_stationarize(),
calibrate_and_plot(),
internal_ts_backward_event_tbl(),
internal_ts_both_event_tbl(),
internal_ts_forward_event_tbl(),
model_extraction_helper(),
ts_get_date_columns(),
ts_is_date_class(),
ts_lag_correlation(),
ts_model_auto_tune(),
ts_model_compare(),
ts_model_rank_tbl(),
ts_model_spec_tune_template(),
ts_qq_plot(),
ts_scedacity_scatter_plot(),
ts_to_tbl(),
util_difflog_ts(),
util_doublediff_ts(),
util_doubledifflog_ts(),
util_log_ts(),
util_singlediff_ts()
ts_info_tbl(AirPassengers)
ts_info_tbl(BJsales)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.