This function will create a generic tuneable model specification, this function
can be used by itself and is called internally by ts_model_auto_tune().
ts_model_spec_tune_template(.parsnip_engine = NULL, .model_spec_class = NULL)A tuneable parsnip model specification.
The model engine that is used by parsnip::set_engine().
The model spec class that is use by parsnip. For
example the 'kernlab' engine can use both svm_poly and svm_rbf.
Steven P. Sanderson II, MPH
This function takes in a single parameter and uses that to output a generic tuneable model specification. This function can work with the following parsnip/modeltime engines:
"auto_arima"
"auto_arima_xgboost"
"ets"
"croston"
"theta"
"smooth_es"
"stlm_ets"
"tbats"
"stlm_arima"
"nnetar"
"prophet"
"prophet_xgboost"
"lm"
"glmnet"
"stan"
"spark"
"keras"
"earth"
"xgboost"
"kernlab"
Other Model Tuning:
ts_model_auto_tune()
Other Utility:
auto_stationarize(),
calibrate_and_plot(),
internal_ts_backward_event_tbl(),
internal_ts_both_event_tbl(),
internal_ts_forward_event_tbl(),
model_extraction_helper(),
ts_get_date_columns(),
ts_info_tbl(),
ts_is_date_class(),
ts_lag_correlation(),
ts_model_auto_tune(),
ts_model_compare(),
ts_model_rank_tbl(),
ts_qq_plot(),
ts_scedacity_scatter_plot(),
ts_to_tbl(),
util_difflog_ts(),
util_doublediff_ts(),
util_doubledifflog_ts(),
util_log_ts(),
util_singlediff_ts()
ts_model_spec_tune_template("ets")
ts_model_spec_tune_template("prophet")
Run the code above in your browser using DataLab